import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

/* Layout */
import Layout from "@/layout";
import DevLayot from "@/layout/developer";

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */


/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
    {
        path: "/login",
        component: () => import("@/views/login/index"),
        hidden: true,
    },
    {
        path: "/register",
        component: () => import("@/views/login/register"),
        hidden: true,
    },
    {
        path: '/',
        redirect: '/home',
        component: Layout,
        children: [{
            path: 'home',
            name: 'AppIndex',
            component: () => import('@/views/app-store/index.vue'),
            meta: { title: '应用管理', icon: 'home' }
        }]
    },
    {
        path: '/',
        redirect: '/dev',
        component: DevLayot,
        children: [{
            path: 'dev',
            name: 'Developer',
            component: () => import('@/views/developer/index.vue'),
            meta: { title: '开发者中心', icon: 'home' }
        }]
    },
    {
        path: '/',
        redirect: '/build',
        component: Layout,
        children: [{
            path: 'build',
            name: 'AppBuild',
            component: () => import('@/views/app-store/build.vue'),
            meta: { title: '打包日志', icon: 'home' }
        }]
    },
    {
        path: '/',
        redirect: '/download',
        component: Layout,
        children: [{
            path: 'download',
            name: 'AppDownload',
            component: () => import('@/views/app-store/download.vue'),
            meta: { title: '下载记录', icon: 'gongzuotai' }
        }]
    },
    {
        path: '/',
        redirect: '/device',
        component: Layout,
        children: [{
            path: 'device',
            name: 'Device',
            component: () => import('@/views/app-store/device.vue'),
            meta: { title: '设备管理', icon: 'gongzuotai' }
        }]
    },
    {
        path: '/',
        redirect: '/profile',
        component: Layout,
        children: [{
            path: 'profile',
            name: 'Profile',
            component: () => import('@/views/profile/index.vue'),
            meta: { title: '个人中心', icon: 'shangcheng' }
        }]
    },
    {
        path: '/',
        redirect: '/docs',
        component: Layout,
        children: [{
            path: 'docs',
            name: 'Document',
            component: () => import('@/views/app-store/docs.vue'),
            meta: { title: '开发文档', icon: 'shangcheng' }
        }]
    },
    {
        path: '/',
        redirect: '/user',
        component: Layout,
        children: [{
            path: 'user',
            name: 'UserIndex',
            component: () => import('@/views/system/users.vue'),
            meta: { title: '用户管理', icon: 'shangcheng' }
        }]
    },
    {
        path: '/',
        redirect: '/404',
        component: Layout,
        children: [{
            path: '404',
            name: 'Page404',
            component: () => import('@/views/error-pages/404'),
            meta: { title: '404', icon: 'home' }
        }]
    },
    {
        path: '/',
        redirect: '/403',
        component: Layout,
        children: [{
            path: '403',
            name: 'Page403',
            component: () => import('@/views/error-pages/403'),
            meta: { title: '403', icon: 'home' }
        }]
    }
];

// 404 page must be placed at the end !!!
export const notFound = { path: '*', redirect: '/404', hidden: true }

export const routerMap = {
    Layout: () => import('@/layout'),
    Home: () => import('@/views/app-store/index'),
    Build: () => import('@/views/app-store/build'),
    Profile: () => import('@/views/profile/index'),
    Download: () => import('@/views/app-store/download'),
    Framework: () => import('@/views/app-store/framework'),
    User: () => import('@/views/system/users'),
}

const createRouter = () =>
    new Router({
        // mode: 'history', // require service support, 后台部署在/static 目录
        // base: "/static", // 应用的基础路径: 默认为'/',修改为'/static'
        scrollBehavior: () => ({ y: 0 }),
        routes: constantRoutes,
    });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
    const newRouter = createRouter();
    router.matcher = newRouter.matcher; // reset router
}

export default router;
